# python-cngal
A Python wrapper for cngal.org API

## 数据来源

1. [数据汇总页面](https://app.cngal.org/data)
2. [Swagger UI](https://api.cngal.org/swagger/index.html)
3. [GitHub 文档](https://github.com/CnGal/CnGalWebSite/blob/master/Docs/AboutCode/APIInstructions/Summary.md)